Changes
=======

Unreleased
----------

Version 0.6.1
-------------

Released 2021-09-12

- Add usage examples and related tests. `#36 <https://github.com/dajiaji/pyseto/pull/36>`__

Version 0.6.0
-------------

Released 2021-09-11

- Add tests for sample code. `#34 <https://github.com/dajiaji/pyseto/pull/34>`__
- Allow int type version for Key.new. `#33 <https://github.com/dajiaji/pyseto/pull/33>`__

Version 0.5.0
-------------

Released 2021-09-11

- Add API reference about Token. `#30 <https://github.com/dajiaji/pyseto/pull/30>`__
- Add support for multiple keys on decode. `#29 <https://github.com/dajiaji/pyseto/pull/29>`__

Version 0.4.0
-------------

Released 2021-09-10

- Add tests for public and fix error message. `#26 <https://github.com/dajiaji/pyseto/pull/26>`__
- Add tests for local and fix error message. `#25 <https://github.com/dajiaji/pyseto/pull/25>`__
- Add tests for Token. `#24 <https://github.com/dajiaji/pyseto/pull/24>`__
- Add tests for Key and fix checking argument. `#22 <https://github.com/dajiaji/pyseto/pull/22>`__
- Add docstrings for KeyInterface. `#21 <https://github.com/dajiaji/pyseto/pull/21>`__

Version 0.3.2
-------------

Released 2021-09-07

- Add API reference. `#17 <https://github.com/dajiaji/pyseto/pull/17>`__

Version 0.3.1
-------------

Released 2021-09-06

- Fix readthedocs build error. `#13 <https://github.com/dajiaji/pyseto/pull/13>`__

Version 0.3.0
-------------

Released 2021-09-06

- Add docs. `#10 <https://github.com/dajiaji/pyseto/pull/10>`__
- Add Key.from_asymmetric_key_params. `#8 <https://github.com/dajiaji/pyseto/pull/8>`__
- Make NotSupportedError public. `#8 <https://github.com/dajiaji/pyseto/pull/8>`__

Version 0.2.0
-------------

Released 2021-09-05

- Add Token object as a response of decode(). `#6 <https://github.com/dajiaji/pyseto/pull/6>`__

Version 0.1.0
-------------

Released 2021-09-05

- First public preview release.
